# type: ignore
from __future__ import annotations

import importlib.metadata

__version__ = importlib.metadata.version("litecli")
